Code documentation
==================

.. automodule:: domain2idna
   :members:

Helpers
-------

Problematic
^^^^^^^^^^^

How can we write, read and delete a file without having to write everytime the same thing?

Code documentation
^^^^^^^^^^^^^^^^^^

.. automodule::domain2idna.helpers
   :members:


:code:`File()`
""""""""""""""

.. autoclass:: domain2idna.helpers.File
    :members:


Converter
---------

Code documentation
^^^^^^^^^^^^^^^^^^

.. automodule::domain2idna.converter
   :members:

.. autoclass:: domain2idna.converter.Converter
    :members:
